# Generated by roxygen2: do not edit by hand

export(longplot)
export(matrixplot)
export(plotup)
export(wideplot)
import(ggplot2)
import(glue)
import(patchwork)
importFrom(RColorBrewer,brewer.pal)
importFrom(forcats,fct_infreq)
importFrom(grDevices,colorRampPalette)
importFrom(gridExtra,grid.arrange)
importFrom(lubridate,is.instant)
importFrom(pander,openFileInOS)
importFrom(rmarkdown,render)
importFrom(stats,chisq.test)
importFrom(stats,density)
importFrom(stats,ftable)
importFrom(stats,reshape)
importFrom(utils,head)
